@@ -17,6 +17,8 @@ def get_location(city, state, zipcode, logger):
   if not data:
     logger.debug(f"geolocate.get_location - Couldn't find location: {city},{state} {zipcode} in cache.")
     data = __get_google_location(city, state, zipcode, logger)
+    if not data:
+      data = __get_google_location(city=None, state=None, zipcode=zipcode, logger=logger)
 
   if data:
     if not from_cache:
@@ -261,8 +263,9 @@ def __get_google_location(city, state, zipcode, logger):
   return None
 
 def __cache_location(city, state, zipcode, location_data, logger):
-  location_string = __get_location_string(city, state, zipcode)
-  location_db_conn.set(location_string, str(location_data))
+  if city and state:
+    location_string = __get_location_string(city, state, zipcode)
+    location_db_conn.set(location_string, str(location_data))
 
 def __get_location_from_cache(city, state, zipcode, logger):
   location = None
